@@ -19,9 +19,13 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any, Iterable, Sequence
 
+from deprecated import deprecated
+
 from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.hooks.emr import EmrContainerHook, EmrHook, EmrServerlessHook
-from airflow.sensors.base import BaseSensorOperator
+from airflow.providers.amazon.aws.hooks.s3 import S3Hook
+from airflow.providers.amazon.aws.links.emr import EmrLogsLink
+from airflow.sensors.base import BaseSensorOperator, poke_mode_only
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -50,18 +54,17 @@ class EmrBaseSensor(BaseSensorOperator):
         self.aws_conn_id = aws_conn_id
         self.target_states: Iterable[str] = []  # will be set in subclasses
         self.failed_states: Iterable[str] = []  # will be set in subclasses
-        self.hook: EmrHook | None = None
 
+    @deprecated(reason="use `hook` property instead.")
     def get_hook(self) -> EmrHook:
-        """Get EmrHook"""
-        if self.hook:
-            return self.hook
-
-        self.hook = EmrHook(aws_conn_id=self.aws_conn_id)
         return self.hook
 
+    @cached_property
+    def hook(self) -> EmrHook:
+        return EmrHook(aws_conn_id=self.aws_conn_id)
+
     def poke(self, context: Context):
-        response = self.get_emr_response()
+        response = self.get_emr_response(context=context)
 
         if response["ResponseMetadata"]["HTTPStatusCode"] != 200:
             self.log.info("Bad HTTP response: %s", response)
@@ -74,15 +77,11 @@ class EmrBaseSensor(BaseSensorOperator):
             return True
 
         if state in self.failed_states:
-            final_message = "EMR job failed"
-            failure_message = self.failure_message_from_response(response)
-            if failure_message:
-                final_message += " " + failure_message
-            raise AirflowException(final_message)
+            raise AirflowException(f"EMR job failed: {self.failure_message_from_response(response)}")
 
         return False
 
-    def get_emr_response(self) -> dict[str, Any]:
+    def get_emr_response(self, context: Context) -> dict[str, Any]:
         """
         Make an API call with boto3 and get response.
 
@@ -93,7 +92,7 @@ class EmrBaseSensor(BaseSensorOperator):
     @staticmethod
     def state_from_response(response: dict[str, Any]) -> str:
         """
-        Get state from response dictionary.
+        Get state from boto3 response.
 
         :param response: response from AWS API
         :return: state
@@ -103,7 +102,7 @@ class EmrBaseSensor(BaseSensorOperator):
     @staticmethod
     def failure_message_from_response(response: dict[str, Any]) -> str | None:
         """
-        Get failure message from response dictionary.
+        Get state from boto3 response.
 
         :param response: response from AWS API
         :return: failure message
@@ -299,6 +298,70 @@ class EmrContainerSensor(BaseSensorOperator):
         return EmrContainerHook(self.aws_conn_id, virtual_cluster_id=self.virtual_cluster_id)
 
 
+class EmrNotebookExecutionSensor(EmrBaseSensor):
+    """
+    Polls the state of the EMR notebook execution until it reaches
+    any of the target states.
+    If a failure state is reached, the sensor throws an error, and fails the task.
+
+    .. seealso::
+        For more information on how to use this sensor, take a look at the guide:
+        :ref:`howto/sensor:EmrNotebookExecutionSensor`
+
+    :param notebook_execution_id: Unique id of the notebook execution to be poked.
+    :target_states: the states the sensor will wait for the execution to reach.
+        Default target_states is ``FINISHED``.
+    :failed_states: if the execution reaches any of the failed_states, the sensor will fail.
+        Default failed_states is ``FAILED``.
+    """
+
+    template_fields: Sequence[str] = ("notebook_execution_id",)
+
+    FAILURE_STATES = {"FAILED"}
+    COMPLETED_STATES = {"FINISHED"}
+
+    def __init__(
+        self,
+        notebook_execution_id: str,
+        target_states: Iterable[str] | None = None,
+        failed_states: Iterable[str] | None = None,
+        **kwargs,
+    ):
+        super().__init__(**kwargs)
+        self.notebook_execution_id = notebook_execution_id
+        self.target_states = target_states or self.COMPLETED_STATES
+        self.failed_states = failed_states or self.FAILURE_STATES
+
+    def get_emr_response(self, context: Context) -> dict[str, Any]:
+        emr_client = self.hook.conn
+        self.log.info("Poking notebook %s", self.notebook_execution_id)
+
+        return emr_client.describe_notebook_execution(NotebookExecutionId=self.notebook_execution_id)
+
+    @staticmethod
+    def state_from_response(response: dict[str, Any]) -> str:
+        """
+        Make an API call with boto3 and get cluster-level details.
+
+        .. seealso::
+            https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr.html#EMR.Client.describe_cluster
+
+        :return: response
+        """
+        return response["NotebookExecution"]["Status"]
+
+    @staticmethod
+    def failure_message_from_response(response: dict[str, Any]) -> str | None:
+        """
+        Get failure message from response dictionary.
+
+        :param response: response from AWS API
+        :return: failure message
+        """
+        cluster_status = response["NotebookExecution"]
+        return cluster_status.get("LastStateChangeReason", None)
+
+
 class EmrJobFlowSensor(EmrBaseSensor):
     """
     Asks for the state of the EMR JobFlow (Cluster) until it reaches
@@ -322,6 +385,7 @@ class EmrJobFlowSensor(EmrBaseSensor):
 
     template_fields: Sequence[str] = ("job_flow_id", "target_states", "failed_states")
     template_ext: Sequence[str] = ()
+    operator_extra_links = (EmrLogsLink(),)
 
     def __init__(
         self,
@@ -336,7 +400,7 @@ class EmrJobFlowSensor(EmrBaseSensor):
         self.target_states = target_states or ["TERMINATED"]
         self.failed_states = failed_states or ["TERMINATED_WITH_ERRORS"]
 
-    def get_emr_response(self) -> dict[str, Any]:
+    def get_emr_response(self, context: Context) -> dict[str, Any]:
         """
         Make an API call with boto3 and get cluster-level details.
 
@@ -345,10 +409,19 @@ class EmrJobFlowSensor(EmrBaseSensor):
 
         :return: response
         """
-        emr_client = self.get_hook().get_conn()
-
+        emr_client = self.hook.conn
         self.log.info("Poking cluster %s", self.job_flow_id)
-        return emr_client.describe_cluster(ClusterId=self.job_flow_id)
+        response = emr_client.describe_cluster(ClusterId=self.job_flow_id)
+        log_uri = S3Hook.parse_s3_url(response["Cluster"]["LogUri"])
+        EmrLogsLink.persist(
+            context=context,
+            operator=self,
+            region_name=self.hook.conn_region_name,
+            aws_partition=self.hook.conn_partition,
+            job_flow_id=self.job_flow_id,
+            log_uri="/".join(log_uri),
+        )
+        return response
 
     @staticmethod
     def state_from_response(response: dict[str, Any]) -> str:
@@ -378,6 +451,7 @@ class EmrJobFlowSensor(EmrBaseSensor):
         return None
 
 
+@poke_mode_only
 class EmrStepSensor(EmrBaseSensor):
     """
     Asks for the state of the step until it reaches any of the target states.
@@ -415,7 +489,7 @@ class EmrStepSensor(EmrBaseSensor):
         self.target_states = target_states or ["COMPLETED"]
         self.failed_states = failed_states or ["CANCELLED", "FAILED", "INTERRUPTED"]
 
-    def get_emr_response(self) -> dict[str, Any]:
+    def get_emr_response(self, context: Context) -> dict[str, Any]:
         """
         Make an API call with boto3 and get details about the cluster step.
 
@@ -424,7 +498,7 @@ class EmrStepSensor(EmrBaseSensor):
 
         :return: response
         """
-        emr_client = self.get_hook().get_conn()
+        emr_client = self.hook.conn
 
         self.log.info("Poking step %s on cluster %s", self.step_id, self.job_flow_id)
         return emr_client.describe_step(ClusterId=self.job_flow_id, StepId=self.step_id)
