@@ -20,7 +20,7 @@ from __future__ import annotations
 import warnings
 from tempfile import NamedTemporaryFile
 from typing import TYPE_CHECKING, Sequence
-from urllib.parse import urlparse
+from urllib.parse import urlsplit
 
 from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.s3 import S3Hook
@@ -53,7 +53,7 @@ class S3ToSFTPOperator(BaseOperator):
         downloading the file from S3.
     """
 
-    template_fields: Sequence[str] = ('s3_key', 'sftp_path')
+    template_fields: Sequence[str] = ("s3_key", "sftp_path", "s3_bucket")
 
     def __init__(
         self,
@@ -61,9 +61,9 @@ class S3ToSFTPOperator(BaseOperator):
         s3_bucket: str,
         s3_key: str,
         sftp_path: str,
-        sftp_conn_id: str = 'ssh_default',
+        sftp_conn_id: str = "ssh_default",
         s3_conn_id: str | None = None,
-        aws_conn_id: str = 'aws_default',
+        aws_conn_id: str = "aws_default",
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -80,8 +80,8 @@ class S3ToSFTPOperator(BaseOperator):
     @staticmethod
     def get_s3_key(s3_key: str) -> str:
         """This parses the correct format for S3 keys regardless of how the S3 url is passed."""
-        parsed_s3_key = urlparse(s3_key)
-        return parsed_s3_key.path.lstrip('/')
+        parsed_s3_key = urlsplit(s3_key)
+        return parsed_s3_key.path.lstrip("/")
 
     def execute(self, context: Context) -> None:
         self.s3_key = self.get_s3_key(self.s3_key)
